@@ -14,10 +14,10 @@ import (
 
 type HCLAttribute struct {
 	hclAttribute *hcl.Attribute
-	ctx          *hcl.EvalContext
+	ctx          *Context
 }
 
-func NewHCLAttribute(attr *hcl.Attribute, ctx *hcl.EvalContext) *HCLAttribute {
+func NewHCLAttribute(attr *hcl.Attribute, ctx *Context) *HCLAttribute {
 	return &HCLAttribute{
 		hclAttribute: attr,
 		ctx:          ctx,
@@ -97,7 +97,7 @@ func (attr *HCLAttribute) Value() (ctyVal cty.Value) {
 			ctyVal = cty.NilVal
 		}
 	}()
-	ctyVal, _ = attr.hclAttribute.Expr.Value(attr.ctx)
+	ctyVal, _ = attr.hclAttribute.Expr.Value(attr.ctx.Inner())
 	if !ctyVal.IsKnown() {
 		return cty.NilVal
 	}
@@ -126,7 +126,7 @@ func (attr *HCLAttribute) ValueAsStrings() []string {
 	if attr == nil {
 		return nil
 	}
-	return getStrings(attr.hclAttribute.Expr, attr.ctx)
+	return getStrings(attr.hclAttribute.Expr, attr.ctx.Inner())
 }
 
 func getStrings(expr hcl.Expression, ctx *hcl.EvalContext) []string {
@@ -166,6 +166,10 @@ func (attr *HCLAttribute) listContains(val cty.Value, stringToLookFor string, ig
 			valueMap := value.AsValueMap()
 			stringToTest = valueMap["key"]
 		}
+		if value.Type().HasDynamicTypes() {
+			// References without a value can't logically "contain" a some string to check against.
+			return false
+		}
 		if !value.IsKnown() {
 			continue
 		}
@@ -305,6 +309,7 @@ func (attr *HCLAttribute) Equals(checkValue interface{}, equalityOptions ...Equa
 		}
 		return attr.Value().RawEquals(checkNumber)
 	}
+
 	return false
 }
 
@@ -606,7 +611,7 @@ func (attr *HCLAttribute) Reference() (*Reference, error) {
 			if err != nil {
 				return nil, err
 			}
-			key, _ := s.Key.Value(attr.ctx)
+			key, _ := s.Key.Value(attr.ctx.Inner())
 			collectionRef.SetKey(key)
 			return collectionRef, nil
 		default:
@@ -629,15 +634,14 @@ func (attr *HCLAttribute) AllReferences() []*Reference {
 	if attr == nil {
 		return nil
 	}
-	refs := attr.referencesInTemplate()
-	if len(refs) > 0 {
-		return refs
-	}
+	var refs []*Reference
+	refs = append(refs, attr.referencesInTemplate()...)
+	refs = append(refs, attr.referencesInConditional()...)
 	ref, err := attr.Reference()
-	if err != nil {
-		return nil
+	if err == nil {
+		refs = append(refs, ref)
 	}
-	return append(refs, ref)
+	return refs
 }
 
 func (attr *HCLAttribute) referencesInTemplate() []*Reference {
@@ -658,6 +662,26 @@ func (attr *HCLAttribute) referencesInTemplate() []*Reference {
 	return refs
 }
 
+func (attr *HCLAttribute) referencesInConditional() []*Reference {
+	if attr == nil {
+		return nil
+	}
+	var refs []*Reference
+	switch t := attr.hclAttribute.Expr.(type) {
+	case *hclsyntax.ConditionalExpr:
+		if ref, err := createDotReferenceFromTraversal(t.TrueResult.Variables()...); err == nil {
+			refs = append(refs, ref)
+		}
+		if ref, err := createDotReferenceFromTraversal(t.FalseResult.Variables()...); err == nil {
+			refs = append(refs, ref)
+		}
+		if ref, err := createDotReferenceFromTraversal(t.Condition.Variables()...); err == nil {
+			refs = append(refs, ref)
+		}
+	}
+	return refs
+}
+
 func (attr *HCLAttribute) IsResourceBlockReference(resourceType string) bool {
 	if attr == nil {
 		return false
@@ -704,3 +728,17 @@ func (attr *HCLAttribute) IsNil() bool {
 func (attr *HCLAttribute) IsNotNil() bool {
 	return !attr.IsNil()
 }
+
+func (attr *HCLAttribute) HasIntersect(checkValues ...interface{}) bool {
+	if !attr.Type().IsListType() && !attr.Type().IsTupleType() {
+		return false
+	}
+
+	for _, item := range checkValues {
+		if attr.Contains(item) {
+			return true
+		}
+	}
+	return false
+
+}
